==> hbci4java_3.0.22+dfsg.orig.tar.xz: hbci4java-hbci4j-core-3.0.22/src/main/java/org/kapott/hbci/manager/IHandlerData.java <==

/*  $Id: IHandlerData.java,v 1.1 2011/05/04 22:37:46 willuhn Exp $

    This file is part of HBCI4Java
    Copyright (C) 2001-2008  Stefan Palme

    HBCI4Java is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    HBCI4Java is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package org.kapott.hbci.manager;

import org.kapott.hbci.passport.HBCIPassport;

// Dieses Interface wird von einigen Klassen implementiert (HBCIHandler,
// HBCIInstitute, HBCIUser). Es dient dazu, ein "allgemeines" Interface
// für alle Klassen zu haben, die sowohl ein Passport als auch einen
// Message-Generator zurückgeben können, also alles, was man zum Ausführen
// von HBCI-Dialogen braucht.
//
// Im Moment ist bei allen Implementierungen dieses Interfaces getMsgGen()
// implementiert, indem this.kernel.getMsgGen() zurückgegeben wird - aber
// das muss nicht so sein!
// 
// TODO: das sieht aus wie ein typisches DesignPattern - das evtl. mal
// irgendwie verallgemeinern (double-linked-parent-child-connection) und überall
// wo nötig einsetzen (evtl. inklusive asserts oder automatischer Setter)

public interface IHandlerData 
{
    public HBCIPassport getPassport();
    public MsgGen       getMsgGen();
}

==> hbci4java_3.1.29+dfsg.orig.tar.xz: hbci4java-hbci4j-core-3.1.29/src/main/java/org/kapott/hbci/manager/IHandlerData.java <==

/*  $Id: IHandlerData.java,v 1.1 2011/05/04 22:37:46 willuhn Exp $

    This file is part of HBCI4Java
    Copyright (C) 2001-2008  Stefan Palme

    HBCI4Java is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    HBCI4Java is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package org.kapott.hbci.manager;

import org.kapott.hbci.passport.HBCIPassport;

// Dieses Interface wird von einigen Klassen implementiert (HBCIHandler,
// HBCIInstitute, HBCIUser). Es dient dazu, ein "allgemeines" Interface
// für alle Klassen zu haben, die sowohl ein Passport als auch einen
// Message-Generator zurückgeben können, also alles, was man zum Ausführen
// von HBCI-Dialogen braucht.
//
// Im Moment ist bei allen Implementierungen dieses Interfaces getMsgGen()
// implementiert, indem this.kernel.getMsgGen() zurückgegeben wird - aber
// das muss nicht so sein!
public interface IHandlerData 
{
    public HBCIPassport getPassport();
    public MsgGen       getMsgGen();
    
    /**
     * Fuehrt eine Neu-Synchronisierung durch.
     * @param force true, wenn die Neu-Synchronisierung forciert werden soll.
     */
    public void sync(boolean force);
}
